@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -23,11 +23,13 @@ around add_file => sub {
   my ( $orig, $self, $file ) = @_;
 
   my @filenames;
+  my $use_finder = 0;
 
   if(@{ $self->finder } > 0) {
     @filenames = map { Path::Class::File->new($_->name)->relative('.')->stringify }
       grep { not ($_->can('is_bytes') and $_->is_bytes) }
       @{ $self->found_files };
+    $use_finder = 1;
   }
 
   $self->$orig(
@@ -45,6 +47,7 @@ around add_file => sub {
           multiple       => \$self->multiple,
           filename_match => join(", ", @{ $self->filename_match }),
           filenames      => [ sort @filenames ],
+          use_finder     => $use_finder,
         },
       ),
     })
@@ -99,17 +102,17 @@ around mvp_multivalue_args => sub {
 __PACKAGE__->meta->make_immutable;
 1;
 
-# ABSTRACT: release Test::Version tests
+# ABSTRACT: Author Test::Version tests
 
 =pod
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Test::Version - release Test::Version tests
+Dist::Zilla::Plugin::Test::Version - Author Test::Version tests
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -121,7 +124,7 @@ in C<dist.ini>
 
 =head1 DESCRIPTION
 
-This module will add a L<Test::Version> test as a release test to your module.
+This module will add a L<Test::Version> test as a author test to your module.
 
 =head1 ATTRIBUTES
 
@@ -179,7 +182,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
@@ -196,7 +199,7 @@ use Test::More;
 # generated by {{ $name }} {{ $version }}
 use Test::Version;
 
-my @imports = qw( {{ @filenames ? 'version_ok' : 'version_all_ok' }} );
+my @imports = qw( {{ $use_finder ? 'version_ok' : 'version_all_ok' }} );
 
 my $params = {
     is_strict      => {{ $is_strict }},
@@ -208,12 +211,11 @@ my $params = {
 push @imports, $params
     if version->parse( $Test::Version::VERSION ) >= version->parse('1.002');
 
-
 Test::Version->import(@imports);
 
 {{
-  @filenames
-  ? join("\n", map { s/'/\\'/g; "version_ok('$_');" } @filenames)
+  $use_finder
+  ? @filenames > 0 ? join("\n", map { s/'/\\'/g; "version_ok('$_');" } @filenames) : '# finder found no files'
   : 'version_all_ok;';
 }}
 done_testing;
